@@ -43,7 +43,7 @@ from numpy import *
 from numpy.linalg import *
 
 __title__      = "pyconsensus"
-__version__    = "0.1.2"
+__version__    = "0.1.4"
 __author__     = "Paul Sztorc and Jack Peterson"
 __license__    = "GPL"
 __maintainer__ = "Jack Peterson"
@@ -313,7 +313,7 @@ class Oracle(object):
             # Decision Outcome -
             # Our best guess for the Decision state (FALSE=0, Ambiguous=.5, TRUE=1)
             # so far (ie, using the present, non-missing, values).
-            DecisionOutcomes_Raw = GetDecisionOutcomes(Mna, ScaledIndex, Rep, Verbose)
+            DecisionOutcomes_Raw = self.GetDecisionOutcomes(Mna, ScaledIndex, Rep, Verbose).squeeze()
 
             # Fill in the predictions to the original M
             NAmat = Mna.mask  # Defines the slice of the matrix which needs to be edited.
